===============================
mily
===============================

.. image:: https://img.shields.io/travis/NSLS-II/mily.svg
        :target: https://travis-ci.org/NSLS-II/mily

.. image:: https://img.shields.io/pypi/v/mily.svg
        :target: https://pypi.python.org/pypi/mily


A collection of Qt building blocks for scientific GUIs.

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://NSLS-II.github.io/mily.

Features
--------

* TODO
